@@ -38,6 +38,8 @@ cthd_INT3400::cthd_INT3400(std::string _uuid) : uuid(_uuid), base_path("") {
 		base_path = "/sys/bus/acpi/devices/INTC1040:00/physical_node/uuids/";
 	} else if (cdev_sysfs.exists("/sys/bus/acpi/devices/INTC1041:00/physical_node/uuids")) {
 		base_path = "/sys/bus/acpi/devices/INTC1041:00/physical_node/uuids/";
+	} else if (cdev_sysfs.exists("/sys/bus/acpi/devices/INTC10A0:00/physical_node/uuids")) {
+		base_path = "/sys/bus/acpi/devices/INTC10A0:00/physical_node/uuids/";
 	}
 	thd_log_info("INT3400 Base path is %s\n", base_path.c_str());
 }
