@@ -97,7 +97,7 @@ int cthd_parse::parser_init(std::string config_file) {
 		xml_config_file = config_file.c_str();
 	}
 
-	/* We have not tested existance yet in this case. */
+	/* We have not tested existence yet in this case. */
 	if (!auto_config) {
 		std::ifstream conf(xml_config_file);
 		if (!conf.is_open()) {
@@ -178,6 +178,7 @@ int cthd_parse::parse_new_trip_cdev(xmlNode * a_node, xmlDoc *doc,
 				} else if(!strcasecmp((const char*) cur_node->name,
 						"PidControl")) {
 					pid_control_t pid_params;
+
 					parse_pid_values(cur_node->children, doc, &pid_params);
 					trip_cdev->pid_param.kp = pid_params.Kp;
 					trip_cdev->pid_param.ki = pid_params.Ki;
@@ -293,6 +294,10 @@ int cthd_parse::parse_pid_values(xmlNode * a_node, xmlDoc *doc,
 	xmlNode *cur_node = NULL;
 	char *tmp_value;
 
+	pid_ptr->Kp = 0.0005;
+	pid_ptr->Ki = 0.0001;
+	pid_ptr->Kd = 0.0001;
+
 	for (cur_node = a_node; cur_node; cur_node = cur_node->next) {
 		if (cur_node->type == XML_ELEMENT_NODE) {
 			DEBUG_PARSER_PRINT("node type: Element, name: %s value: %s\n", cur_node->name, xmlNodeListGetString(doc, cur_node->xmlChildrenNode, 1));
@@ -810,6 +815,10 @@ void cthd_parse::dump_thermal_conf() {
 					thermal_info_list[i].cooling_devs[l].max_state);
 			thd_log_info("\t\tStep: %d\n",
 					thermal_info_list[i].cooling_devs[l].inc_dec_step);
+			thd_log_info("\t\tReadBack: %d\n",
+					thermal_info_list[i].cooling_devs[l].read_back);
+			thd_log_info("\t\tDebouncePeriod: %d\n",
+					thermal_info_list[i].cooling_devs[l].debounce_interval);
 			thd_log_info("\t\tAutoDownControl: %d\n",
 					thermal_info_list[i].cooling_devs[l].auto_down_control);
 			if (thermal_info_list[i].cooling_devs[l].pid_enable) {
