@@ -106,7 +106,7 @@ bool ThermaldInterface::initialize()
     if (z_count.isValid()) {
         zone_count = z_count;
     } else {
-        qCritical() << "error from" << iface->interface() << "=" << cdev_count.error();
+        qCritical() << "error from" << iface->interface() << "=" << z_count.error();
         return false;
     }
 
@@ -141,7 +141,7 @@ bool ThermaldInterface::initialize()
                 }
             }
         }
-        // Store the actual number of trips, as opposed to the theoritical maximum
+        // Store the actual number of trips, as opposed to the theoretical maximum
         zones[i].trip_count = zones[i].trips.count();
 
         // Store the first valid trip temp for the zone
@@ -379,6 +379,7 @@ int ThermaldInterface::getTripCountForZone(uint zone)
 
 int ThermaldInterface::getTripTempForZone(uint zone, uint trip)
 {
+
     if (zone < (uint)zones.count()){
         if (trip < zones[zone].trip_count){
             return zones[zone].trips[trip].temp;
@@ -453,7 +454,9 @@ int ThermaldInterface::getZoneInformation(uint index, zoneInformationType &info)
         info.name = result.arguments().at(0).toString();
         info.sensor_count = result.arguments().at(1).toInt();
         info.trip_count = result.arguments().at(2).toInt();
+        info.active = result.arguments().at(3).toInt();
         info.lowest_valid_index = 0;
+        info.id = index;
         return 0;
     } else {
         qCritical() << "error from" << iface->interface() <<  result.errorMessage();
